@@ -60,23 +60,26 @@ def my_process(data):
 
     if opts.raw:
         print("Raw data: {}".format(ev.raw_data))
+    noopt = True
     if opts.eddy:
+        noopt = False
         xx = EddyStone().decode(ev)
         if xx:
             print("Google Beacon {}".format(xx))
-    elif opts.ruuvi:
+            return
+    if opts.ruuvi:
+        noopt = False
         xx = RuuviWeather().decode(ev)
         if xx:
             print("Weather info {}".format(xx))
-    elif opts.pebble:
-        xx = BlueMaestro().decode(ev)
-        if xx:
-            print("Pebble info {}".format(xx))
-    elif opts.atcmi:
+            return
+    if opts.atcmi:
+        noopt = False
         xx = ATCMiThermometer().decode(ev)
         if xx:
             print("Temperature info {}".format(xx))
-    else:
+            return
+    if noopt:
         ev.show(0)
 
 
@@ -105,13 +108,6 @@ def main(args=None):
         default=False,
         help="Look only for Ruuvi tag Weather station messages",
     )
-    parser.add_argument(
-        "-p",
-        "--pebble",
-        action="store_true",
-        default=False,
-        help="Look only for Pebble Environment Monitor",
-    )
     parser.add_argument(
         "-A",
         "--atcmi",
